@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -35,8 +35,24 @@ G_BEGIN_DECLS
 #define GPM_BUGZILLA_URL		"http://bugzilla.gnome.org/buglist.cgi?product=gnome-power-manager"
 #define GPM_FAQ_URL			"http://live.gnome.org/GnomePowerManager/Faq"
 
-char		*gpm_get_timestring		(int		time);
-void		 gpm_warning_beep		(void);
+typedef enum {
+	GPM_ICON_POLICY_ALWAYS,
+	GPM_ICON_POLICY_PRESENT,
+	GPM_ICON_POLICY_CHARGE,
+	GPM_ICON_POLICY_CRITICAL,
+	GPM_ICON_POLICY_NEVER
+} GpmIconPolicy;
+
+gchar		*gpm_get_timestring		(guint		 time);
+guint		 gpm_percent_to_discrete	(guint		 percentage,
+						 guint		 levels);
+gint		 gpm_exponential_average	(gint		 previous,
+						 gint		 new,
+						 guint		 slew);
+guint		 gpm_discrete_to_percent	(guint		 discrete,
+						 guint		 levels);
+GpmIconPolicy	 gpm_tray_icon_mode_from_string	(const gchar	*mode);
+const gchar	*gpm_tray_icon_mode_to_string	(GpmIconPolicy	 mode);
 
 G_END_DECLS
 
