@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  *
  * Licensed under the GNU General Public License Version 2
@@ -118,6 +118,11 @@ gpm_srv_backlight_sync_policy (GpmSrvBacklight *srv_backlight)
 	GpmDpmsMethod method;
 	GpmAcAdapterState state;
 
+	/* no point processing if we can't do the dpms action */
+	if (srv_backlight->priv->can_dpms == FALSE) {
+		return;
+	}
+
 	/* get the ac state */
 	gpm_ac_adapter_get_state (srv_backlight->priv->ac_adapter, &state);
 
@@ -329,22 +334,28 @@ conf_key_changed_cb (GpmConf          *conf,
 
 	if (strcmp (key, GPM_CONF_AC_BRIGHTNESS) == 0) {
 
-		gpm_conf_get_int (srv_backlight->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
-		if (state == GPM_AC_ADAPTER_PRESENT) {
-			gpm_brightness_lcd_set_std (srv_backlight->priv->brightness, value);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_conf_get_int (srv_backlight->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
+			if (state == GPM_AC_ADAPTER_PRESENT) {
+				gpm_brightness_lcd_set_std (srv_backlight->priv->brightness, value);
+			}
 		}
 
 	} else if (strcmp (key, GPM_CONF_BATTERY_BRIGHTNESS) == 0) {
 
-		gpm_conf_get_int (srv_backlight->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
-		if (state == GPM_AC_ADAPTER_MISSING) {
-			gpm_brightness_lcd_set_std (srv_backlight->priv->brightness, value);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_conf_get_int (srv_backlight->priv->conf, GPM_CONF_BATTERY_BRIGHTNESS, &value);
+			if (state == GPM_AC_ADAPTER_MISSING) {
+				gpm_brightness_lcd_set_std (srv_backlight->priv->brightness, value);
+			}
 		}
 
 	} else if (strcmp (key, GPM_CONF_PANEL_DIM_BRIGHTNESS) == 0) {
 
-		gpm_conf_get_int (srv_backlight->priv->conf, GPM_CONF_PANEL_DIM_BRIGHTNESS, &value);
-		gpm_brightness_lcd_set_dim (srv_backlight->priv->brightness, value);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_conf_get_int (srv_backlight->priv->conf, GPM_CONF_PANEL_DIM_BRIGHTNESS, &value);
+			gpm_brightness_lcd_set_dim (srv_backlight->priv->brightness, value);
+		}
 	}
 
 	if (strcmp (key, GPM_CONF_BATTERY_SLEEP_DISPLAY) == 0 ||
@@ -379,7 +390,7 @@ ac_adapter_changed_cb (GpmAcAdapter      *ac_adapter,
 
 	/* only do brightness changes if we have the hardware */
 	gpm_conf_get_bool (srv_backlight->priv->conf, GPM_CONF_DISPLAY_STATE_CHANGE, &do_laptop_lcd);
-	if (do_laptop_lcd) {
+	if (do_laptop_lcd == TRUE && srv_backlight->priv->can_dim == TRUE) {
 		gpm_brightness_lcd_set_std (srv_backlight->priv->brightness, value);
 	}
 }
@@ -400,19 +411,24 @@ button_pressed_cb (GpmButton        *button,
 
 	if (strcmp (type, GPM_BUTTON_BRIGHT_UP) == 0) {
 
-		gpm_brightness_lcd_up (srv_backlight->priv->brightness);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_up (srv_backlight->priv->brightness);
+		}
 
 	} else if (strcmp (type, GPM_BUTTON_BRIGHT_DOWN) == 0) {
 
-		gpm_brightness_lcd_down (srv_backlight->priv->brightness);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_down (srv_backlight->priv->brightness);
+		}
 
 	} else if (strcmp (type, GPM_BUTTON_LID_OPEN) == 0) {
 
 		/* make sure we undim when we lift the lid */
-		gpm_brightness_lcd_undim (srv_backlight->priv->brightness);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_undim (srv_backlight->priv->brightness);
+		}
+		gpm_srv_backlight_sync_policy (srv_backlight);	
 	}
-
-	gpm_srv_backlight_sync_policy (srv_backlight);	
 }
 
 /**
@@ -427,8 +443,8 @@ button_pressed_cb (GpmButton        *button,
  * session timeout has elapsed for the idle action.
  **/
 static void
-idle_changed_cb (GpmIdle             *idle,
-		 GpmIdleMode          mode,
+idle_changed_cb (GpmIdle         *idle,
+		 GpmIdleMode      mode,
 		 GpmSrvBacklight *srv_backlight)
 {
 	GpmAcAdapterState state;
@@ -442,11 +458,6 @@ idle_changed_cb (GpmIdle             *idle,
 		gpm_conf_get_bool (srv_backlight->priv->conf, GPM_CONF_BATTERY_IDLE_DIM, &laptop_do_dim);
 	}
 
-	/* should we ignore this? */
-	if (laptop_do_dim == FALSE) {
-		return;
-	}
-
 	/* don't dim or undim the screen when the lid is closed */
 	if (gpm_button_is_lid_closed (srv_backlight->priv->button) == TRUE) {
 		return;
@@ -455,31 +466,41 @@ idle_changed_cb (GpmIdle             *idle,
 	if (mode == GPM_IDLE_MODE_NORMAL) {
 
 		/* deactivate display power management */
-		error = NULL;
-		gpm_dpms_set_active (srv_backlight->priv->dpms, FALSE, &error);
-		if (error) {
-			gpm_debug ("Unable to set DPMS not active: %s", error->message);
+		if (srv_backlight->priv->can_dpms == TRUE) {
+			error = NULL;
+			gpm_dpms_set_active (srv_backlight->priv->dpms, FALSE, &error);
+			if (error) {
+				gpm_debug ("Unable to set DPMS not active: %s", error->message);
+				g_error_free (error);
+			}
 		}
 
 		/* sync timeouts */
 		gpm_srv_backlight_sync_policy (srv_backlight);
 
-		gpm_brightness_lcd_undim (srv_backlight->priv->brightness);
+		if (laptop_do_dim == TRUE && srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_undim (srv_backlight->priv->brightness);
+		}
 
 	} else if (mode == GPM_IDLE_MODE_SESSION) {
 
 		/* activate display power management */
-		error = NULL;
-		gpm_dpms_set_active (srv_backlight->priv->dpms, TRUE, &error);
-		if (error) {
-			gpm_debug ("Unable to set DPMS active: %s", error->message);
+		if (srv_backlight->priv->can_dpms == TRUE) {
+			error = NULL;
+			gpm_dpms_set_active (srv_backlight->priv->dpms, TRUE, &error);
+			if (error) {
+				gpm_debug ("Unable to set DPMS active: %s", error->message);
+				g_error_free (error);
+			}
 		}
 
 		/* sync timeouts */
 		gpm_srv_backlight_sync_policy (srv_backlight);
 
 		/* Dim the screen, fixes #328564 */
-		gpm_brightness_lcd_dim (srv_backlight->priv->brightness);
+		if (laptop_do_dim == TRUE && srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_dim (srv_backlight->priv->brightness);
+		}
 	}
 }
 
@@ -618,7 +639,8 @@ gpm_srv_backlight_class_init (GpmSrvBacklightClass *klass)
 static void
 gpm_srv_backlight_init (GpmSrvBacklight *srv_backlight)
 {
-	gint value;
+	GpmAcAdapterState state;
+	guint value;
 
 	srv_backlight->priv = GPM_SRV_BACKLIGHT_GET_PRIVATE (srv_backlight);
 
@@ -634,26 +656,39 @@ gpm_srv_backlight_init (GpmSrvBacklight *srv_backlight)
 	g_signal_connect (srv_backlight->priv->conf, "value-changed",
 			  G_CALLBACK (conf_key_changed_cb), srv_backlight);
 
+	/* watch for brightness up and down buttons and also check lid state */
+	srv_backlight->priv->button = gpm_button_new ();
+	g_signal_connect (srv_backlight->priv->button, "button-pressed",
+			  G_CALLBACK (button_pressed_cb), srv_backlight);
+
+	/* we use ac_adapter for the ac-adapter-changed signal */
+	srv_backlight->priv->ac_adapter = gpm_ac_adapter_new ();
+	g_signal_connect (srv_backlight->priv->ac_adapter, "ac-adapter-changed",
+			  G_CALLBACK (ac_adapter_changed_cb), srv_backlight);
+
 	if (srv_backlight->priv->can_dim == TRUE) {
 		/* watch for manual brightness changes (for the feedback widget) */
 		srv_backlight->priv->brightness = gpm_brightness_lcd_new ();
 		g_signal_connect (srv_backlight->priv->brightness, "brightness-changed",
 				  G_CALLBACK (brightness_changed_cb), srv_backlight);
 
+		/* set the standard setting */
+		gpm_ac_adapter_get_state (srv_backlight->priv->ac_adapter, &state);
+		if (state == GPM_AC_ADAPTER_PRESENT) {
+			gpm_conf_get_uint (srv_backlight->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
+		} else {
+			gpm_conf_get_uint (srv_backlight->priv->conf, GPM_CONF_BATTERY_BRIGHTNESS, &value);
+		}
+		gpm_brightness_lcd_set_std (srv_backlight->priv->brightness, value);
+
 		/* set the default dim */
-		gpm_conf_get_int (srv_backlight->priv->conf, GPM_CONF_PANEL_DIM_BRIGHTNESS, &value);
+		gpm_conf_get_uint (srv_backlight->priv->conf, GPM_CONF_PANEL_DIM_BRIGHTNESS, &value);
 		gpm_brightness_lcd_set_dim (srv_backlight->priv->brightness, value);
 
 		/* use a visual widget */
 		srv_backlight->priv->feedback = gpm_feedback_new ();
 		gpm_feedback_set_icon_name (srv_backlight->priv->feedback,
 					    GPM_STOCK_BRIGHTNESS_LCD);
-
-		/* watch for brightness up and down buttons */
-		srv_backlight->priv->button = gpm_button_new ();
-		g_signal_connect (srv_backlight->priv->button, "button-pressed",
-				  G_CALLBACK (button_pressed_cb), srv_backlight);
-
 	}
 
 	if (srv_backlight->priv->can_dpms == TRUE) {
@@ -668,11 +703,6 @@ gpm_srv_backlight_init (GpmSrvBacklight *srv_backlight)
 				  G_CALLBACK (control_resume_cb), srv_backlight);
 	}
 
-	/* we use ac_adapter for the ac-adapter-changed signal */
-	srv_backlight->priv->ac_adapter = gpm_ac_adapter_new ();
-	g_signal_connect (srv_backlight->priv->ac_adapter, "ac-adapter-changed",
-			  G_CALLBACK (ac_adapter_changed_cb), srv_backlight);
-
 	/* watch for idle mode changes */
 	srv_backlight->priv->idle = gpm_idle_new ();
 	g_signal_connect (srv_backlight->priv->idle, "idle-changed",
