@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -87,10 +87,6 @@ G_DEFINE_TYPE (GpmStatistics, gpm_statistics, G_TYPE_OBJECT)
 #define ACTION_BLANK_TEXT		_("Blank screen")
 #define ACTION_NOTHING_TEXT		_("Do nothing")
 
-#define	GPM_DBUS_SERVICE		"org.gnome.PowerManager"
-#define	GPM_DBUS_PATH			"/org/gnome/PowerManager"
-#define	GPM_DBUS_INTERFACE		"org.gnome.PowerManager"
-
 /**
  * gpm_statistics_class_init:
  * @klass: This graph class instance
@@ -331,6 +327,26 @@ gpm_statistics_checkbox_legend_cb (GtkWidget *widget,
 	gpm_graph_widget_enable_legend (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), checked);
 }
 
+/**
+ * gpm_statistics_checkbox_axis_labels_cb:
+ * @widget: The GtkWidget object
+ * @gpm_pref_key: The GConf key for this preference setting.
+ **/
+static void
+gpm_statistics_checkbox_axis_labels_cb (GtkWidget *widget,
+			    GpmStatistics  *statistics)
+{
+	gboolean checked;
+
+	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+	gpm_debug ("axis labels enable %i", checked);
+
+	/* save to gconf so we open next time with the correct setting */
+	gpm_conf_set_bool (statistics->priv->conf, GPM_CONF_STAT_SHOW_AXIS_LABELS, checked);
+
+	gpm_graph_widget_enable_axis_labels (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), checked);
+}
+
 /**
  * gpm_statistics_convert_strv_to_glist:
  *
@@ -364,7 +380,7 @@ gpm_statistics_find_types (GpmStatistics *statistics,
 		return FALSE;
 	}	
 
-	ret = dbus_g_proxy_call (proxy, "GetTypes", &error,
+	ret = dbus_g_proxy_call (proxy, "GetDataTypes", &error,
 			         G_TYPE_INVALID,
 			         G_TYPE_STRV, &strlist,
 			         G_TYPE_INVALID);
@@ -497,7 +513,7 @@ gpm_statistics_get_axis_type_dbus (GpmStatistics          *statistics,
 		return FALSE;
 	}	
 
-	ret = dbus_g_proxy_call (proxy, "GetAxisType", &error,
+	ret = dbus_g_proxy_call (proxy, "GetAxisTypes", &error,
 			         G_TYPE_STRING, type,
 			         G_TYPE_INVALID,
 			         G_TYPE_STRING, &axis_type_x,
@@ -509,7 +525,7 @@ gpm_statistics_get_axis_type_dbus (GpmStatistics          *statistics,
 	}
 	if (ret == FALSE) {
 		/* abort as the DBUS method failed */
-		gpm_warning ("GetAxisType failed!");
+		gpm_warning ("GetAxisTypes failed!");
 		return FALSE;
 	}
 
@@ -535,7 +551,7 @@ gpm_statistics_refresh_data (GpmStatistics *statistics)
 
 	list = gpm_info_data_get_list (statistics->priv->data);
 
-	gpm_graph_widget_set_data (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), list);
+	gpm_graph_widget_set_data (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), list, 0);
 
 	gtk_widget_hide (GTK_WIDGET (statistics->priv->graph_widget));
 	gtk_widget_show (GTK_WIDGET (statistics->priv->graph_widget));
@@ -551,6 +567,10 @@ gpm_statistics_type_combo_changed_cb (GtkWidget      *widget,
 	GpmGraphWidgetAxisType axis_y = GPM_GRAPH_WIDGET_TYPE_INVALID;
 
 	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
+	if (value == NULL) {
+		gpm_debug ("no graph types available");
+		return;
+	}
 	if (strcmp (value, ACTION_CHARGE_TEXT) == 0) {
 		type = ACTION_CHARGE;
 	} else if (strcmp (value, ACTION_POWER_TEXT) == 0) {
@@ -566,8 +586,8 @@ gpm_statistics_type_combo_changed_cb (GtkWidget      *widget,
 
 	/* find out what sort of grid axis we need */
 	gpm_statistics_get_axis_type_dbus (statistics, type, &axis_x, &axis_y);
-	gpm_graph_widget_set_axis_x (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), axis_x);
-	gpm_graph_widget_set_axis_y (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), axis_y);
+	gpm_graph_widget_set_axis_type_x (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), axis_x);
+	gpm_graph_widget_set_axis_type_y (GPM_GRAPH_WIDGET (statistics->priv->graph_widget), axis_y);
 
 	/* const, so no need to free */
 	statistics->priv->graph_type = type;
@@ -717,7 +737,8 @@ gpm_statistics_init (GpmStatistics *statistics)
 	widget = glade_xml_get_widget (statistics->priv->glade_xml, "custom_graph");
 	gtk_widget_set_size_request (widget, 600, 300);
 	statistics->priv->graph_widget = widget;
-	gpm_graph_widget_set_axis_y (GPM_GRAPH_WIDGET (widget), GPM_GRAPH_WIDGET_TYPE_PERCENTAGE);
+	gpm_graph_widget_set_axis_type_x (GPM_GRAPH_WIDGET (widget), GPM_GRAPH_WIDGET_TYPE_TIME);
+	gpm_graph_widget_set_axis_type_y (GPM_GRAPH_WIDGET (widget), GPM_GRAPH_WIDGET_TYPE_PERCENTAGE);
 
 	/* add the key items */
 	gpm_graph_widget_key_add (GPM_GRAPH_WIDGET (widget),
@@ -818,6 +839,13 @@ gpm_statistics_init (GpmStatistics *statistics)
 			  G_CALLBACK (gpm_statistics_checkbox_legend_cb), statistics);
 	gpm_statistics_checkbox_legend_cb (widget, statistics);
 
+	widget = glade_xml_get_widget (statistics->priv->glade_xml, "checkbutton_axis");
+	gpm_conf_get_bool (statistics->priv->conf, GPM_CONF_STAT_SHOW_AXIS_LABELS, &checked);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
+	g_signal_connect (widget, "clicked",
+			  G_CALLBACK (gpm_statistics_checkbox_axis_labels_cb), statistics);
+	gpm_statistics_checkbox_axis_labels_cb (widget, statistics);
+
 	gtk_widget_show (main_window);
 	g_timeout_add (GPM_STATISTICS_POLL_INTERVAL,
 		       gpm_statistics_graph_refresh, statistics);
